@@ -36,73 +36,6 @@ _MANIFEST_ONLY_LANGUAGE = "manifest-only"
 _PYTHON_LANGUAGE_TAG = f"language:{_PYTHON_LANGUAGE}"
 _MANIFEST_ONLY_TAG = f"language:{_MANIFEST_ONLY_LANGUAGE}"
 
-_LOWCODE_CONNECTORS_NEEDING_PYTHON: list[str] = [
-    "source-alpha-vantage",
-    "source-amplitude",
-    "source-apify-dataset",
-    "source-asana",
-    "source-avni",
-    "source-aws-cloudtrail",
-    "source-bamboo-hr",
-    "source-braintree",
-    "source-braze",
-    "source-chargebee",
-    "source-commercetools",
-    "source-eventbrite",
-    "source-facebook-pages",
-    "source-fastbill",
-    "source-freshdesk",
-    "source-gitlab",
-    "source-gnews",
-    "source-gong",
-    "source-greenhouse",
-    "source-instagram",
-    "source-instatus",
-    "source-intercom",
-    "source-iterable",
-    "source-jina-ai-reader",
-    "source-jira",
-    "source-klaviyo",
-    "source-looker",
-    "source-mailchimp",
-    "source-mixpanel",
-    "source-monday",
-    "source-my-hours",
-    "source-notion",
-    "source-okta",
-    "source-orb",
-    "source-outreach",
-    "source-paypal-transaction",
-    "source-pinterest",
-    "source-pipedrive",
-    "source-pocket",
-    "source-posthog",
-    "source-prestashop",
-    "source-public-apis",
-    "source-qualaroo",
-    "source-railz",
-    "source-recharge",
-    "source-recurly",
-    "source-retently",
-    "source-rss",
-    "source-salesloft",
-    "source-service-now",
-    "source-slack",
-    "source-surveymonkey",
-    "source-the-guardian-api",
-    "source-tiktok-marketing",
-    "source-trello",
-    "source-typeform",
-    "source-us-census",
-    "source-xero",
-    "source-younium",
-    "source-zendesk-chat",
-    "source-zendesk-sunshine",
-    "source-zendesk-support",
-    "source-zendesk-talk",
-    "source-zenloop",
-    "source-zoom",
-]
 _LOWCODE_CONNECTORS_FAILING_VALIDATION: list[str] = []
 # Connectors that return 404 or some other misc exception.
 _LOWCODE_CONNECTORS_UNEXPECTED_ERRORS: list[str] = [
@@ -115,7 +48,6 @@ _LOWCODE_CDK_FILE_NOT_FOUND_ERRORS: list[str] = []
 _LOWCODE_CONNECTORS_EXCLUDED: list[str] = [
     *_LOWCODE_CONNECTORS_FAILING_VALIDATION,
     *_LOWCODE_CONNECTORS_UNEXPECTED_ERRORS,
-    *_LOWCODE_CONNECTORS_NEEDING_PYTHON,
     *_LOWCODE_CDK_FILE_NOT_FOUND_ERRORS,
 ]
 
